@@ -205,7 +205,7 @@ function replaceUrl(fetchurl, oldurl, shortener) {
     }
     xhrs.send();
 }
-
+/*
 function getTranslateUrl(text, toLang) {
     console.log("getting translate url");
     console.log("translang: " + translang)
@@ -217,9 +217,6 @@ function getTranslateUrl(text, toLang) {
 function getTranslatedText(xhrz) {
 
     if (xhrz.readyState == XMLHttpRequest.DONE) {
-        /* console.log(xhrz.status);
-        console.log(xhrz.responseText); */
-
         var j = eval("(" + xhrz.responseText + ")");
         if (j.data.translations.length > 0) {
             return j.data.translations[0].translatedText;
@@ -229,6 +226,9 @@ function getTranslatedText(xhrz) {
     }
 }
 
+*/
+
+
 function getLangList() {
     var langs = [
     {
